@@ -21,7 +21,11 @@ let get name =
 
 let get_from_cache lib =
   try
-    Hashtbl.find pkgs_cache lib.Libname.main_name
+    let (fp,pkg) = Hashtbl.find pkgs_cache lib.Libname.main_name in
+    if (List.length lib.Libname.subnames) > 0 then
+      (fp, Meta.Pkg.find lib.Libname.subnames pkg)
+    else
+      (fp,pkg)
   with Not_found ->
     failwith (Printf.sprintf "package %s not found in the hashtbl: internal error" (Libname.to_string lib))
 
